CometChatCallAction enum

Call action from the push payload.

Inheritance
Available extensions

Values

initiated → const CometChatCallAction

The call has been initiated (incoming call).

cancelled → const CometChatCallAction

The call was cancelled by the caller.

unanswered → const CometChatCallAction

The call went unanswered.

ongoing → const CometChatCallAction

The call is ongoing (connected).

rejected → const CometChatCallAction

The call was rejected by the receiver.

ended → const CometChatCallAction

The call has ended.

busy → const CometChatCallAction

The receiver is busy on another call.

unknown → const CometChatCallAction

An unrecognized call action.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String? value) CometChatCallAction
Parses a string value into a CometChatCallAction.

Constants

values → const List<CometChatCallAction>
A constant List of the values in this enum, in order of their declaration.