CometChatDefaultCallScreen class
Default incoming call screen shown when no custom screen builder is provided.
Displays the caller's name and call type at the top, the caller's avatar in the middle, and Accept / Decline action buttons at the bottom.
To override this screen, provide a CometChatNotificationConfig.customCallScreenBuilder.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- CometChatDefaultCallScreen
Constructors
- CometChatDefaultCallScreen({Key? key, required CometChatCallDetails callDetails, required VoidCallback onAccept, required VoidCallback onDecline})
-
Creates a CometChatDefaultCallScreen.
const
Properties
- callDetails → CometChatCallDetails
-
The call details for the incoming call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAccept → VoidCallback
-
Callback invoked when the user taps the Accept button.
final
- onDecline → VoidCallback
-
Callback invoked when the user taps the Decline button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited