onCallAccepted property

CometChatCallAcceptedCallback? onCallAccepted
final

Called when the user accepts an incoming call from the default call screen.

Use this to start your WebRTC/media engine, navigate to the ongoing call screen, and call CometChatPushNotifications.setCallConnected.

Not invoked when customCallScreenBuilder is provided.

Implementation

final CometChatCallAcceptedCallback? onCallAccepted;