showInAppNotifications property

bool showInAppNotifications
final

Whether to show in-app chat notifications when the app is in the foreground.

When false (default), chat push notifications received while the app is in the foreground are suppressed (not displayed as banners). When true, they are shown as in-app notification banners.

Implementation

final bool showInAppNotifications;