showInAppVoIP property

bool showInAppVoIP
final

Whether to show the VoIP incoming call screen when the app is in the foreground.

When false (default/recommended), incoming call pushes received while the app is in the foreground are suppressed — the UIKit's CallEventService handles foreground calls via WebSocket and shows IncomingCallOverlay instead. The call event is still emitted on the CometChatPushNotifications.onCallEvent stream. When true, the push SDK also shows the system call notification in foreground (use only if CallEventService is NOT active).

Implementation

final bool showInAppVoIP;