CometChatNotificationException class

Exception thrown by the CometChat notifications plugin.

Implemented types

Constructors

CometChatNotificationException({required CometChatErrorCode code, required String message, Object? cause})
Creates a CometChatNotificationException.
const

Properties

cause Object?
The underlying cause of the error, if any.
final
code CometChatErrorCode
The error code identifying the type of failure.
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description of the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited