CometChatPushPayload class

Represents a parsed CometChat push notification payload.

The raw payload has the structure:

{
  "trigger": "push-notification-payload-generated",
  "data": {
    "to": { "uid": "..." },
    "notificationDetails": { ... }
  }
}

This model represents the parsed notificationDetails with the to uid.

Constructors

CometChatPushPayload({required String toUid, required CometChatNotificationDetails notificationDetails, required Map<String, dynamic> rawPayload})
Creates a CometChatPushPayload instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
notificationDetails CometChatNotificationDetails
The notification details extracted from the payload.
final
rawPayload Map<String, dynamic>
The raw payload map for fallback access.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toUid String
The UID of the intended recipient.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited