getLaunchCallDetails method
Returns the pending call details captured from the launch intent (if the app was launched by tapping an incoming call notification).
Returns null if the app was not launched from a call notification.
The buffer is cleared after reading.
Implementation
@override
Future<Map<String, dynamic>?> getLaunchCallDetails() async {
final result = await methodChannel.invokeMapMethod<String, dynamic>(
'getLaunchCallDetails',
);
return result;
}