setIncomingCallLaunchHandler method

  1. @override
void setIncomingCallLaunchHandler(
  1. void handler(
    1. Map<String, dynamic> details
    )
)
override

Registers a handler for call notification taps that occur while the app is already running (e.g., tapping a call notification after putting the app in background).

Implementation

@override
void setIncomingCallLaunchHandler(
  void Function(Map<String, dynamic> details) handler,
) {
  _incomingCallLaunchHandler = handler;
  _ensureMethodCallHandlerSet();
}