getLaunchCallDetails method

Future<Map<String, dynamic>?> getLaunchCallDetails()

Returns the pending call details captured from the launch intent (if the app was launched by tapping an incoming call notification).

Returns null if the app was not launched from a call notification. The buffer is cleared after reading.

Implementation

Future<Map<String, dynamic>?> getLaunchCallDetails() {
  throw UnimplementedError(
    'getLaunchCallDetails() has not been implemented.',
  );
}