setIncomingCallLaunchHandler method
Registers a handler for call notification taps that occur while the app is already running (e.g., tapping a call notification after putting the app in background).
Implementation
void setIncomingCallLaunchHandler(
void Function(Map<String, dynamic> details) handler,
) {
throw UnimplementedError(
'setIncomingCallLaunchHandler() has not been implemented.',
);
}